@@ -6,7 +6,6 @@
 import os
 
 import pytest
-from flaky import flaky
 
 from nbconvert.exporters.qt_screenshot import QT_INSTALLED
 from nbconvert.exporters.qtpng import QtPNGExporter
@@ -20,7 +19,7 @@ class TestQtPNGExporter(ExportersTestsBase):
 
     exporter_class = QtPNGExporter  # type:ignore
 
-    @flaky
+    @pytest.mark.flaky
     def test_export(self):
         """
         Can a TemplateExporter export something?
@@ -28,7 +27,7 @@ class TestQtPNGExporter(ExportersTestsBase):
         if os.name == "nt":
             # currently not supported
             with pytest.raises(RuntimeError):
-                (output, resources) = QtPNGExporter().from_filename(self._get_notebook())
+                (output, _resources) = QtPNGExporter().from_filename(self._get_notebook())
         else:
-            (output, resources) = QtPNGExporter().from_filename(self._get_notebook())
+            (output, _resources) = QtPNGExporter().from_filename(self._get_notebook())
             assert len(output) > 0
